{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.

  Invenio RDM Records is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
#}

<dd>
  <a href="/coming-soon" class="ui button"><i class="envelope icon"></i> Send message</a>
</dd>
