{#
Copyright (C) 2022 CERN.

Invenio RDM Records is free software; you can redistribute it and/or modify
it under the terms of the MIT License; see LICENSE file for more details.
#}

{% if permissions is defined and permissions.can_edit and not is_preview %}
  <section id="record-manage-menu"
           aria-label="{{ _('Record management') }}"
           class="ui grid segment computer only rdm-sidebar"
  >
    <div class="column"
         id="recordManagement"
         data-record='{{ record | tojson }}'
         data-permissions='{{ permissions | tojson }}'
    >
    </div>
  </section>
{% endif %}
